@@ -8,6 +8,15 @@ from subprocess import check_output, CalledProcessError
 from .configgenerator import ConfigGenerator
 
 
+RH_ALLOW_SHA1 = '''
+[openssl_init]
+alg_section = evp_properties
+
+[evp_properties]
+rh-allow-sha1-signatures = yes
+'''
+
+
 class OpenSSLGenerator(ConfigGenerator):
     CONFIG_NAME = 'openssl'
     SCOPES = {'tls', 'ssl', 'openssl'}
@@ -227,6 +236,9 @@ class OpenSSLConfigGenerator(OpenSSLGenerator):
                     for i in p['sign'] if i in cls.sign_map]
         s += 'SignatureAlgorithms = ' + ':'.join(sig_algs) + '\n'
 
+        if 'SHA1' in p['hash']:
+            s += RH_ALLOW_SHA1
+
         return s
 
     @classmethod
